# qt_material-stubs

## Installation

```
pip install qt_material-stubs
```

## Style Guidelines

Follow the same style guidelines as [typeshed](https://github.com/python/typeshed/blob/master/CONTRIBUTING.md).
